<?php

namespace FreshMail;

use Db;
use Language;
use Module;
use Tab;

class Installer implements Interfaces\Installer
{
    use Hooks;

    private $tabs = [
//        'AdminFreshmailDashboard' => 'Dasboard',
        [ 'controller' => 'AdminFreshmailSubscribers', 'name' => 'List of subscribers', 'icon' => 'list'],
        [ 'controller' => 'AdminFreshmailConfig', 'name' => 'Configuration', 'icon' => 'settings'],
        [ 'controller' => 'AdminFreshmailFormConfig', 'name' => 'Forms', 'icon' => 'settings_applications'],
//        [ 'controller' => 'AdminFreshmailAbandonedCartConfig', 'name' => 'Abandoned cart', 'icon' => 'settings_applications'],

//        'AdminFreshmailRaports' => 'Reports',
//        'AdminFreshmailTemplates' => 'Template',
    ];

    private $module;

    public function __construct(Module $module)
    {
        $this->module = $module;
    }


    public function install(): bool
    {
        $return = $this->installMenuAdmin();
        foreach ($this->getHooks() as $hook) {
            $return &= $this->module->registerHook($hook);
        }

        return $return
            && $this->loadSQLFile(__DIR__ . '/../../install/install.sql');
    }


    public function uninstall(): bool
    {
        $result = true;
        foreach ($this->tabs as $tab) {
            $result &= $this->uninstallTab($tab['controller']);
        }

        return $result
            && $this->uninstallTab('AdminFreshmailWizard')
            && $this->uninstallTab('AdminFreshmail')
            && $this->loadSQLFile(__DIR__ . '/../../install/uninstall.sql');

    }

    public function installMenuAdmin()
    {
        $result = $this->installTab('AdminFreshmail', 'FRESHMAIL')
            && $this->installTab('AdminFreshmailWizard', 'AdminFreshmailWizard', false, true);

        foreach ($this->tabs as $tab) {
            $this->installTab($tab['controller'], $tab['name'], 'AdminFreshmail', false, $tab['icon']);
        }

        return $result;
    }

    public function installTab($controllerClassName, $tabName, $tabParentControllerName = false, $withoutTab = false, $icon = '')
    {
        $tab = new Tab();

        $tab->active = 1;
        $tab->class_name = $controllerClassName;
        $tab->name = [];
        $tab->icon = $icon;

        foreach (Language::getLanguages(true) as $lang) {
            $tab->name[$lang['id_lang']] = $this->module->l($tabName);
        }

        if ($withoutTab) {
            $tab->id_parent = -1;
        } elseif ($tabParentControllerName) {
            $tab->id_parent = (int)Tab::getIdFromClassName($tabParentControllerName);
        } else {
            $tab->id_parent = 0;
        }

        $tab->module = $this->module->name;

        return $tab->add();
    }

    /**
     * @param $controllerClassName
     * @return bool
     */
    public function uninstallTab($controllerClassName)
    {
        $idTab = (int)Tab::getIdFromClassName($controllerClassName);

        if ($idTab) {
            $tab = new Tab($idTab);
            return $tab->delete();
        }
        return false;
    }

    public function loadSQLFile($sqlFile)
    {
        $sqlContent = file_get_contents($sqlFile);
        $sqlContent = str_replace('PREFIX_', _DB_PREFIX_, $sqlContent);
        $sqlRequests = preg_split("/;\s*[\r\n]+/", $sqlContent);

        $result = true;

        foreach ($sqlRequests as $request) {
            if (!empty($request)) {
                $result &= Db::getInstance()->execute(trim($request));
            }
        }

        return $result;
    }

}